@@ -1,5 +1,5 @@
 package Mercury::Pattern::PushPull;
-our $VERSION = '0.015';
+our $VERSION = '0.016';
 # ABSTRACT: Manage a push/pull pattern for a single topic
 
 #pod =head1 SYNOPSIS
@@ -42,7 +42,7 @@ our $VERSION = '0.015';
 #pod
 #pod =cut
 
-use Mojo::Base 'Mojo';
+use Mojo::Base '-base';
 
 #pod =attr pullers
 #pod
@@ -182,7 +182,7 @@ Mercury::Pattern::PushPull - Manage a push/pull pattern for a single topic
 
 =head1 VERSION
 
-version 0.015
+version 0.016
 
 =head1 SYNOPSIS
 
@@ -277,7 +277,7 @@ Doug Bell <preaction@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2016 by Doug Bell.
+This software is copyright (c) 2018 by Doug Bell.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
